/**
@author   Cody Johnson
@email    cody.ele@noritake.com (Feel free to ask questions)
@website  noritake-elec.com
@version  v1.1 (ME-N58-1)
@ide      IAR
@brief    GT-CP command library for STM32F4xx and Noritake GT-CP series sodules

@vertatim
Provide the GT-CP commands between STM32F4Discovery and Noritake GT-CP series modules.
@endverbatim
*/

#ifndef GTCP_H
#define GTCP_H

#include "stm32f4xx.h"
#include "stm32f4xx_i2c.h"

void GTCP_Init(unsigned width, unsigned height);
void GTCP_print(char data);
void GTCP_back();
void GTCP_forward();
void GTCP_lineFeed();
void GTCP_home();
void GTCP_carriageReturn();
void GTCP_crlf();
void GTCP_XY(unsigned x, unsigned y);
void GTCP_XY1(unsigned x, unsigned y);
void GTCP_usCommand();
void GTCP_setCursor(unsigned x, unsigned y);
void GTCP_clearScreen();
void GTCP_lineClear();
void GTCP_lineEndClear();
void GTCP_cursorOn();
void GTCP_cursorOff();
void GTCP_reset();
void GTCP_8by16DotMode();
void GTCP_writeScreenMode(uint8_t mode);
void GTCP_writeMixtureDisplayMode(uint8_t mode);
void GTCP_useMultiByteChars(uint8_t enable);
void GTCP_setMultiByteCharSet(uint8_t code);
void GTCP_setFontSize(uint8_t size);
void GTCP_setOutlineFontType(uint8_t fontType);
void GTCP_useCustomChars(uint8_t enable);
uint8_t GTCP_getColumn(uint8_t *src, int col);
void GTCP_defineCustomChar(uint8_t codeStart, uint8_t codeEnd, uint8_t format, uint8_t xDir, uint8_t *data);
void GTCP_deleteCustomChar(uint8_t type, uint8_t code);
void GTCP_setAsciiVariant(uint8_t code);
void GTCP_setCharSet(uint8_t code);
void GTCP_setScrollMode(uint8_t mode);
void GTCP_setHorizScrollSpeed(uint8_t speed);
void GTCP_invertOff();
void GTCP_invertOn();
void GTCP_setCompositionMode(uint8_t mode);
void GTCP_setScreenBrightness(unsigned level);
void GTCP_wait(uint8_t wait);
void GTCP_shortWait(uint8_t time);
void GTCP_scrollScreen(unsigned x, unsigned y, unsigned times, uint8_t speed);
void GTCP_curtainAction(uint8_t direction, uint8_t speed, uint8_t red, uint8_t green, uint8_t blue);
void GTCP_springAction(uint8_t direction, uint8_t speed, unsigned x, unsigned y);
void GTCP_randomAction(uint8_t actionType, uint8_t speed, unsigned x, unsigned y);
void GTCP_fadeInAction(uint8_t speed, unsigned x, unsigned y);
void GTCP_fadeOutAction(uint8_t speed);
void GTCP_blinkScreenOff();
void GTCP_blinkScreenOn(uint8_t enable, uint8_t reverse, uint8_t onTime, uint8_t offTime, uint8_t cycles);
void GTCP_displayOff();
void GTCP_displayOn();
void GTCP_screenSaver(uint8_t mode);
void GTCP_setFontStyle(uint8_t proportional, uint8_t evenSpacing);
void GTCP_setFontMagnification(uint8_t x, uint8_t y, uint8_t tall);
void GTCP_selectWindow(uint8_t window);
void GTCP_defineWindow(uint8_t window, unsigned x, unsigned y, unsigned width, unsigned height);
void GTCP_deleteWindow(uint8_t window);
void GTCP_joinScreens();
void GTCP_separateScreens();
void GTCP_drawImage(unsigned width, unsigned height, uint8_t format, char *data);
void GTCP_pixelDrawing(uint8_t pen, unsigned x, unsigned y);
void GTCP_drawLineBox(uint8_t mode, uint8_t pen, unsigned xStart, unsigned yStart, unsigned xEnd, unsigned yEnd);
void GTCP_storedBitImageDraw(uint8_t memory, unsigned address, unsigned extension, unsigned xDefine, unsigned xSize, unsigned ySize, uint8_t format);
void GTCP_setCharacterStyle(uint8_t style);
void GTCP_setCharacterColor(uint8_t red, uint8_t green, uint8_t blue);
void GTCP_setBackgroundColor(uint8_t red, uint8_t green, uint8_t blue);
void GTCP_enterUserSetupMode();
void GTCP_endUserSetupMode();
void GTCP_touchDataEnable(uint8_t enable);
void GTCP_touchChannel(uint8_t channel);
void GTCP_touchModeSelect(uint8_t mode);
void GTCP_coordinatesMode(uint8_t channel);
void GTCP_switchMatrixMode(uint8_t channel, uint8_t switchesX, uint8_t switchesY, uint8_t clearanceX, uint8_t clearanceY);
void GTCP_IOPortSetting(uint8_t portSetting);
void GTCP_IOPortOutput(uint8_t portValue);
void GTCP_IOPortInput();
void GTCP_MemorySWSetting(uint8_t memorySW, uint8_t data);
void GTCP_MemorySWSettingMulti(uint8_t numSettings, uint8_t *data);
void GTCP_MemorySWDataSend(uint8_t switchNum);
void GTCP_MemorySWDataSendMulti(uint8_t numReads, uint8_t *data);
void GTCP_16x16CharacterDefinition(uint8_t codeUpper, uint8_t codeLower, uint8_t *data);
void GTCP_16x16CharacterDelete(uint8_t codeUpper, uint8_t codeLower);
void GTCP_32x32CharacterDefinition(uint8_t codeUpper, uint8_t codeLower, uint8_t *data);
void GTCP_32x32CharacterDelete(uint8_t codeUpper, uint8_t codeLower);
void GTCP_downloadCharacterSave(uint8_t fontSize);
void GTCP_downloadCharacterRestore(uint8_t fontSize);
void GTCP_FROMUserFontDefinition(uint8_t table, uint8_t *data);
void GTCP_RAMMacroDefineDelete(uint8_t lengthUpper, uint8_t lengthLower, uint8_t *data);
void GTCP_FROMMacroDefineDelete(uint8_t registrationNum, uint8_t lengthUpper, uint8_t lengthLower, uint8_t interval, uint8_t idleTime, uint8_t *data);
void GTCP_macroExecution(uint8_t definitionNum, uint8_t interval, uint8_t idleTime);
void GTCP_macroEndCondition(uint8_t endCodeEnable, uint8_t endCode, uint8_t endScreenSetting);
void GTCP_memoryStore(uint8_t sizeUpper, uint8_t sizeLower, uint8_t sizeExtension, uint8_t memorySelect, uint8_t addressUpper, uint8_t addressLower, uint8_t addressExtension, uint8_t *data);
void GTCP_memoryTransfer(uint8_t sizeUpper, uint8_t sizeLower, uint8_t sizeExtension, uint8_t destMemory, uint8_t destAddressUpper, uint8_t destAddressLower, uint8_t destAddressExtension, uint8_t srcMemory, uint8_t srcAddressUpper, uint8_t srcAddressLower, uint8_t srcAddressExtension);
void GTCP_memorySend(uint8_t sizeUpper, uint8_t sizeLower, uint8_t sizeExtension, uint8_t memorySelect, uint8_t addressUpper, uint8_t addressLower, uint8_t addressExtension);
void GTCP_displayStatusSend(uint8_t statusType, uint8_t address, uint8_t length);
void GTCP_touchSettingPackageDataStore(uint8_t packageNum, uint8_t *data);
void GTCP_touchSettingPackageSelection(uint8_t packageNum);

#endif